@@ -136,6 +136,11 @@ def main():
         # Both gene and group was assigned, dataset was confirmed
         V.generate_dataset(opt)
 
+        for group in V.dict_dataset:
+            for gene in V.dict_dataset[group]:
+                for FI in V.dict_dataset[group][gene].list_qr_FI:
+                    print(f"{group} {gene} {FI.hash} {FI.id}")
+
         # Appending outgroup
         logging.info("Appending outgroup")
         # For non-concatenated outgroup
